@@ -157,11 +157,21 @@ class CliApplication():
         else:
             # print(response.json())
             data = response.json()
-            if data["result"]["error"]:
-                print(data["result"]["error"])
+            try:
+                if data["result"]["error"]:
+                    print(data["result"]["error"])
+                    sys.exit()
+                else:
+                    return []
+            except KeyError:
+                if data["error"]:
+                    print(data["error"])
+                    sys.exit()
+                else:
+                    return []
+            except:
+                traceback.print_exc()
                 sys.exit()
-            else:
-                return []
 
     def pushCodeInRepo(self, commit, repo, branch, codefile):
         # print(commit, repo)
